# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Router(Base):
	"""The Router class encapsulates a user managed router node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Router property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'router'

	def __init__(self, parent):
		super(Router, self).__init__(parent)

	@property
	def CustomTlv(self):
		"""An instance of the CustomTlv class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtlv.CustomTlv)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtlv import CustomTlv
		return CustomTlv(self)

	@property
	def CustomTopology(self):
		"""An instance of the CustomTopology class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopology.CustomTopology)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopology import CustomTopology
		return CustomTopology(self)

	@property
	def DceMulticastIpv4GroupRange(self):
		"""An instance of the DceMulticastIpv4GroupRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dcemulticastipv4grouprange.DceMulticastIpv4GroupRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dcemulticastipv4grouprange import DceMulticastIpv4GroupRange
		return DceMulticastIpv4GroupRange(self)

	@property
	def DceMulticastIpv6GroupRange(self):
		"""An instance of the DceMulticastIpv6GroupRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dcemulticastipv6grouprange.DceMulticastIpv6GroupRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dcemulticastipv6grouprange import DceMulticastIpv6GroupRange
		return DceMulticastIpv6GroupRange(self)

	@property
	def DceMulticastMacRange(self):
		"""An instance of the DceMulticastMacRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dcemulticastmacrange.DceMulticastMacRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dcemulticastmacrange import DceMulticastMacRange
		return DceMulticastMacRange(self)

	@property
	def DceNetworkRange(self):
		"""An instance of the DceNetworkRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dcenetworkrange.DceNetworkRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dcenetworkrange import DceNetworkRange
		return DceNetworkRange(self)

	@property
	def DceTopologyRange(self):
		"""An instance of the DceTopologyRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dcetopologyrange.DceTopologyRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dcetopologyrange import DceTopologyRange
		return DceTopologyRange(self)

	@property
	def Interface(self):
		"""An instance of the Interface class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.interface.Interface)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.interface import Interface
		return Interface(self)

	@property
	def LearnedInformation(self):
		"""An instance of the LearnedInformation class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.learnedinformation.LearnedInformation)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.learnedinformation import LearnedInformation
		return LearnedInformation(self)._select()

	@property
	def NetworkRange(self):
		"""An instance of the NetworkRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.networkrange.NetworkRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.networkrange import NetworkRange
		return NetworkRange(self)

	@property
	def RouteRange(self):
		"""An instance of the RouteRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.routerange.RouteRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.routerange import RouteRange
		return RouteRange(self)

	@property
	def SpbNetworkRange(self):
		"""An instance of the SpbNetworkRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.spbnetworkrange.SpbNetworkRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.spbnetworkrange import SpbNetworkRange
		return SpbNetworkRange(self)

	@property
	def SpbTopologyRange(self):
		"""An instance of the SpbTopologyRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.spbtopologyrange.SpbTopologyRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.spbtopologyrange import SpbTopologyRange
		return SpbTopologyRange(self)

	@property
	def TrillPingOam(self):
		"""An instance of the TrillPingOam class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.trillpingoam.TrillPingOam)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.trillpingoam import TrillPingOam
		return TrillPingOam(self)._select()

	@property
	def TrillUnicastMacRange(self):
		"""An instance of the TrillUnicastMacRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.trillunicastmacrange.TrillUnicastMacRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.trillunicastmacrange import TrillUnicastMacRange
		return TrillUnicastMacRange(self)

	@property
	def AreaAddressList(self):
		"""The list of area addresses to use.

		Returns:
			list(str)
		"""
		return self._get_attribute('areaAddressList')
	@AreaAddressList.setter
	def AreaAddressList(self, value):
		self._set_attribute('areaAddressList', value)

	@property
	def AreaAuthType(self):
		"""Sets up authentication for Level 1 LSPs.

		Returns:
			str(none|password|md5)
		"""
		return self._get_attribute('areaAuthType')
	@AreaAuthType.setter
	def AreaAuthType(self, value):
		self._set_attribute('areaAuthType', value)

	@property
	def AreaReceivedPasswordList(self):
		"""If areaAuthType is isisAuthTypePassword, then this is a list of passwords that the router will accept on received LSPs.

		Returns:
			list(str)
		"""
		return self._get_attribute('areaReceivedPasswordList')
	@AreaReceivedPasswordList.setter
	def AreaReceivedPasswordList(self, value):
		self._set_attribute('areaReceivedPasswordList', value)

	@property
	def AreaTransmitPassword(self):
		"""If areaAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted LSPs.

		Returns:
			str
		"""
		return self._get_attribute('areaTransmitPassword')
	@AreaTransmitPassword.setter
	def AreaTransmitPassword(self, value):
		self._set_attribute('areaTransmitPassword', value)

	@property
	def BroadcastRootPriority(self):
		"""DEPRECATED The value of the Broadcast Root Priority of a particular DCE ISIS router.

		Returns:
			number
		"""
		return self._get_attribute('broadcastRootPriority')
	@BroadcastRootPriority.setter
	def BroadcastRootPriority(self, value):
		self._set_attribute('broadcastRootPriority', value)

	@property
	def CapabilityRouterId(self):
		"""DEPRECATED The IPv4 address format of the Capability Router.

		Returns:
			str
		"""
		return self._get_attribute('capabilityRouterId')
	@CapabilityRouterId.setter
	def CapabilityRouterId(self, value):
		self._set_attribute('capabilityRouterId', value)

	@property
	def DeviceId(self):
		"""DEPRECATED This is a deprecated attribute in DCE ISIS mode.

		Returns:
			number
		"""
		return self._get_attribute('deviceId')
	@DeviceId.setter
	def DeviceId(self, value):
		self._set_attribute('deviceId', value)

	@property
	def DevicePriority(self):
		"""DEPRECATED This is a deprecated attribute in DCE ISIS mode.

		Returns:
			number
		"""
		return self._get_attribute('devicePriority')
	@DevicePriority.setter
	def DevicePriority(self, value):
		self._set_attribute('devicePriority', value)

	@property
	def DomainAuthType(self):
		"""DEPRECATED Sets up authentication for Level 2 LSPs.

		Returns:
			str(none|password|md5)
		"""
		return self._get_attribute('domainAuthType')
	@DomainAuthType.setter
	def DomainAuthType(self, value):
		self._set_attribute('domainAuthType', value)

	@property
	def DomainReceivedPasswordList(self):
		"""DEPRECATED If domainAuthType is isisAuthTypePassword, then this is a list of passwords that the router will accept on received LSPs.

		Returns:
			list(str)
		"""
		return self._get_attribute('domainReceivedPasswordList')
	@DomainReceivedPasswordList.setter
	def DomainReceivedPasswordList(self, value):
		self._set_attribute('domainReceivedPasswordList', value)

	@property
	def DomainTransmitPassword(self):
		"""DEPRECATED If domainAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted LSPs.

		Returns:
			str
		"""
		return self._get_attribute('domainTransmitPassword')
	@DomainTransmitPassword.setter
	def DomainTransmitPassword(self, value):
		self._set_attribute('domainTransmitPassword', value)

	@property
	def EnableAttached(self):
		"""DEPRECATED Indicates that the Attached Flag is set. It indicates that this ISIS router can use L2 routing to reach other areas.

		Returns:
			bool
		"""
		return self._get_attribute('enableAttached')
	@EnableAttached.setter
	def EnableAttached(self, value):
		self._set_attribute('enableAttached', value)

	@property
	def EnableAutoLoopback(self):
		"""DEPRECATED If enabled, loopback addresses are allowed in the generated routes.

		Returns:
			bool
		"""
		return self._get_attribute('enableAutoLoopback')
	@EnableAutoLoopback.setter
	def EnableAutoLoopback(self, value):
		self._set_attribute('enableAutoLoopback', value)

	@property
	def EnableDiscardLearnedLsps(self):
		"""DEPRECATED If enabled, LSPs learned from this router's interfaces will be discarded.

		Returns:
			bool
		"""
		return self._get_attribute('enableDiscardLearnedLsps')
	@EnableDiscardLearnedLsps.setter
	def EnableDiscardLearnedLsps(self, value):
		self._set_attribute('enableDiscardLearnedLsps', value)

	@property
	def EnableHelloPadding(self):
		"""DEPRECATED If true, enables padding of hello messages.

		Returns:
			bool
		"""
		return self._get_attribute('enableHelloPadding')
	@EnableHelloPadding.setter
	def EnableHelloPadding(self, value):
		self._set_attribute('enableHelloPadding', value)

	@property
	def EnableHitlessRestart(self):
		"""DEPRECATED Hitless Restart is enabled for this emulated ISIS router.

		Returns:
			bool
		"""
		return self._get_attribute('enableHitlessRestart')
	@EnableHitlessRestart.setter
	def EnableHitlessRestart(self, value):
		self._set_attribute('enableHitlessRestart', value)

	@property
	def EnableHostName(self):
		"""DEPRECATED If true, the given dynamic host name is transmitted in all the packets sent from this router.

		Returns:
			bool
		"""
		return self._get_attribute('enableHostName')
	@EnableHostName.setter
	def EnableHostName(self, value):
		self._set_attribute('enableHostName', value)

	@property
	def EnableIgnoreMtPortCapability(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableIgnoreMtPortCapability')
	@EnableIgnoreMtPortCapability.setter
	def EnableIgnoreMtPortCapability(self, value):
		self._set_attribute('enableIgnoreMtPortCapability', value)

	@property
	def EnableIgnoreRecvMd5(self):
		"""DEPRECATED MD5 authentication will be disabled for incoming/received packets.

		Returns:
			bool
		"""
		return self._get_attribute('enableIgnoreRecvMd5')
	@EnableIgnoreRecvMd5.setter
	def EnableIgnoreRecvMd5(self, value):
		self._set_attribute('enableIgnoreRecvMd5', value)

	@property
	def EnableMtIpv6(self):
		"""DEPRECATED If checked in L3, emulation type traffic group ID at router level is grayed out and unassigned.

		Returns:
			bool
		"""
		return self._get_attribute('enableMtIpv6')
	@EnableMtIpv6.setter
	def EnableMtIpv6(self, value):
		self._set_attribute('enableMtIpv6', value)

	@property
	def EnableMtuProbe(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableMtuProbe')
	@EnableMtuProbe.setter
	def EnableMtuProbe(self, value):
		self._set_attribute('enableMtuProbe', value)

	@property
	def EnableMultiTopology(self):
		"""DEPRECATED Enables more than one topology (distribution tree) corresponding to the given R bridge.

		Returns:
			bool
		"""
		return self._get_attribute('enableMultiTopology')
	@EnableMultiTopology.setter
	def EnableMultiTopology(self, value):
		self._set_attribute('enableMultiTopology', value)

	@property
	def EnableOverloaded(self):
		"""DEPRECATED If enabled, the LSP Database Overload Bit is set. It indicates that the LSP database on this router is overloaded and that there is not enough memory to store a received LSP. This router enters the Waiting State and floods an LSP (with LSP number = 0) with the overload bit set, so other routers will not forward ISIS packets to it.

		Returns:
			bool
		"""
		return self._get_attribute('enableOverloaded')
	@EnableOverloaded.setter
	def EnableOverloaded(self, value):
		self._set_attribute('enableOverloaded', value)

	@property
	def EnablePartitionRepair(self):
		"""DEPRECATED Enables the optional partition repair option specified in ISO/IEC 10589 and RFC 1195 for Level 1 areas.

		Returns:
			bool
		"""
		return self._get_attribute('enablePartitionRepair')
	@EnablePartitionRepair.setter
	def EnablePartitionRepair(self, value):
		self._set_attribute('enablePartitionRepair', value)

	@property
	def EnableTrillOam(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableTrillOam')
	@EnableTrillOam.setter
	def EnableTrillOam(self, value):
		self._set_attribute('enableTrillOam', value)

	@property
	def EnableWideMetric(self):
		"""DEPRECATED Enables the use of extended reachability (wide) metrics (defined to support TE): 32-bits wide for IP reachability (routes) and 24-bits wide for IS reachability (IS neighbors). If TE is enabled, wide metrics will be enabled automatically. The wide metrics may be used without enabling TE, however.

		Returns:
			bool
		"""
		return self._get_attribute('enableWideMetric')
	@EnableWideMetric.setter
	def EnableWideMetric(self, value):
		self._set_attribute('enableWideMetric', value)

	@property
	def Enabled(self):
		"""DEPRECATED Enables or disables the simulated router.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def FTagValue(self):
		"""DEPRECATED This is a deprecated attribute in DCE ISIS mode.

		Returns:
			number
		"""
		return self._get_attribute('fTagValue')
	@FTagValue.setter
	def FTagValue(self, value):
		self._set_attribute('fTagValue', value)

	@property
	def FilterIpv4MulticastTlvs(self):
		"""DEPRECATED If true, retrieves IPv4 Multicast learned information in the DCE ISIS mode.

		Returns:
			bool
		"""
		return self._get_attribute('filterIpv4MulticastTlvs')
	@FilterIpv4MulticastTlvs.setter
	def FilterIpv4MulticastTlvs(self, value):
		self._set_attribute('filterIpv4MulticastTlvs', value)

	@property
	def FilterIpv6MulticastTlvs(self):
		"""DEPRECATED If true, retrieves IPv6 Multicast learned information in the DCE ISIS mode.

		Returns:
			bool
		"""
		return self._get_attribute('filterIpv6MulticastTlvs')
	@FilterIpv6MulticastTlvs.setter
	def FilterIpv6MulticastTlvs(self, value):
		self._set_attribute('filterIpv6MulticastTlvs', value)

	@property
	def FilterLearnedIpv4Prefixes(self):
		"""DEPRECATED If true, retrieves IPv4 Unicast learned information in the ISIS L3 Routing mode.

		Returns:
			bool
		"""
		return self._get_attribute('filterLearnedIpv4Prefixes')
	@FilterLearnedIpv4Prefixes.setter
	def FilterLearnedIpv4Prefixes(self, value):
		self._set_attribute('filterLearnedIpv4Prefixes', value)

	@property
	def FilterLearnedIpv6Prefixes(self):
		"""DEPRECATED If true, retrieves IPv6 Unicast learned information in the ISIS L3 Routing mode.

		Returns:
			bool
		"""
		return self._get_attribute('filterLearnedIpv6Prefixes')
	@FilterLearnedIpv6Prefixes.setter
	def FilterLearnedIpv6Prefixes(self, value):
		self._set_attribute('filterLearnedIpv6Prefixes', value)

	@property
	def FilterLearnedRbridges(self):
		"""DEPRECATED If true, retrieves RBridges learned information in the DCE ISIS mode.

		Returns:
			bool
		"""
		return self._get_attribute('filterLearnedRbridges')
	@FilterLearnedRbridges.setter
	def FilterLearnedRbridges(self, value):
		self._set_attribute('filterLearnedRbridges', value)

	@property
	def FilterLearnedSpbRbridges(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('filterLearnedSpbRbridges')
	@FilterLearnedSpbRbridges.setter
	def FilterLearnedSpbRbridges(self, value):
		self._set_attribute('filterLearnedSpbRbridges', value)

	@property
	def FilterLearnedTrillMacUnicast(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('filterLearnedTrillMacUnicast')
	@FilterLearnedTrillMacUnicast.setter
	def FilterLearnedTrillMacUnicast(self, value):
		self._set_attribute('filterLearnedTrillMacUnicast', value)

	@property
	def FilterMacMulticastTlvs(self):
		"""DEPRECATED If true, retrieves MAC Multicast learned information in the DCE ISIS mode.

		Returns:
			bool
		"""
		return self._get_attribute('filterMacMulticastTlvs')
	@FilterMacMulticastTlvs.setter
	def FilterMacMulticastTlvs(self, value):
		self._set_attribute('filterMacMulticastTlvs', value)

	@property
	def HostName(self):
		"""DEPRECATED Allows to add a host name to this router.

		Returns:
			str
		"""
		return self._get_attribute('hostName')
	@HostName.setter
	def HostName(self, value):
		self._set_attribute('hostName', value)

	@property
	def InterLspMgroupPduBurstGap(self):
		"""DEPRECATED Indicates the gap between each LSP MGROUP-PDUs.

		Returns:
			number
		"""
		return self._get_attribute('interLspMgroupPduBurstGap')
	@InterLspMgroupPduBurstGap.setter
	def InterLspMgroupPduBurstGap(self, value):
		self._set_attribute('interLspMgroupPduBurstGap', value)

	@property
	def LspLifeTime(self):
		"""DEPRECATED (in sec) The MaxAge for retaining a learned LSP on this router. The default value is 1,200 sec.

		Returns:
			number
		"""
		return self._get_attribute('lspLifeTime')
	@LspLifeTime.setter
	def LspLifeTime(self, value):
		self._set_attribute('lspLifeTime', value)

	@property
	def LspMaxSize(self):
		"""DEPRECATED (in bytes) The maximum allowable length of an ISIS LSP message. The default is 1,492 bytes.

		Returns:
			number
		"""
		return self._get_attribute('lspMaxSize')
	@LspMaxSize.setter
	def LspMaxSize(self, value):
		self._set_attribute('lspMaxSize', value)

	@property
	def LspMgroupPduMinTransmissionInterval(self):
		"""DEPRECATED Indicates the minimum wait time for each LSP MGROUP-PDU transmission.

		Returns:
			number
		"""
		return self._get_attribute('lspMgroupPduMinTransmissionInterval')
	@LspMgroupPduMinTransmissionInterval.setter
	def LspMgroupPduMinTransmissionInterval(self, value):
		self._set_attribute('lspMgroupPduMinTransmissionInterval', value)

	@property
	def LspRefreshRate(self):
		"""DEPRECATED (in sec) The rate at which LSPs are resent. The default value is 900 sec.

		Returns:
			number
		"""
		return self._get_attribute('lspRefreshRate')
	@LspRefreshRate.setter
	def LspRefreshRate(self, value):
		self._set_attribute('lspRefreshRate', value)

	@property
	def MaxAreaAddresses(self):
		"""DEPRECATED The number of area addresses permitted for this IS area.

		Returns:
			number
		"""
		return self._get_attribute('maxAreaAddresses')
	@MaxAreaAddresses.setter
	def MaxAreaAddresses(self, value):
		self._set_attribute('maxAreaAddresses', value)

	@property
	def MaxLspMgroupPdusPerBurst(self):
		"""DEPRECATED Indicates the maximum number of LSP MGROUP-PDUs for each burst.

		Returns:
			number
		"""
		return self._get_attribute('maxLspMgroupPdusPerBurst')
	@MaxLspMgroupPdusPerBurst.setter
	def MaxLspMgroupPdusPerBurst(self, value):
		self._set_attribute('maxLspMgroupPdusPerBurst', value)

	@property
	def NumberOfMtuProbes(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('numberOfMtuProbes')
	@NumberOfMtuProbes.setter
	def NumberOfMtuProbes(self, value):
		self._set_attribute('numberOfMtuProbes', value)

	@property
	def NumberOfMultiDestinationTrees(self):
		"""DEPRECATED The number of Multi-Destination Trees for the emulated DCE ISIS router.

		Returns:
			number
		"""
		return self._get_attribute('numberOfMultiDestinationTrees')
	@NumberOfMultiDestinationTrees.setter
	def NumberOfMultiDestinationTrees(self, value):
		self._set_attribute('numberOfMultiDestinationTrees', value)

	@property
	def OriginatingLspBufSize(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('originatingLspBufSize')
	@OriginatingLspBufSize.setter
	def OriginatingLspBufSize(self, value):
		self._set_attribute('originatingLspBufSize', value)

	@property
	def PsnpInterval(self):
		"""DEPRECATED The PSPN Interval.

		Returns:
			number
		"""
		return self._get_attribute('psnpInterval')
	@PsnpInterval.setter
	def PsnpInterval(self, value):
		self._set_attribute('psnpInterval', value)

	@property
	def RestartMode(self):
		"""DEPRECATED If enableHitlessRestart is true, this indicates the mode in which this router is to operate.

		Returns:
			str(normalRouter|restartingRouter|startingRouter|helperRouter)
		"""
		return self._get_attribute('restartMode')
	@RestartMode.setter
	def RestartMode(self, value):
		self._set_attribute('restartMode', value)

	@property
	def RestartTime(self):
		"""DEPRECATED Enter the restart time in seconds.

		Returns:
			number
		"""
		return self._get_attribute('restartTime')
	@RestartTime.setter
	def RestartTime(self, value):
		self._set_attribute('restartTime', value)

	@property
	def RestartVersion(self):
		"""DEPRECATED If enableHitlessRestart is true, this indicates the version of the draft-ietf-isis-restart-nn document that the router should conform to.

		Returns:
			str(version3|version4)
		"""
		return self._get_attribute('restartVersion')
	@RestartVersion.setter
	def RestartVersion(self, value):
		self._set_attribute('restartVersion', value)

	@property
	def StartFtagValue(self):
		"""DEPRECATED The starting FTAG value of the emulated DCE ISIS router.

		Returns:
			number
		"""
		return self._get_attribute('startFtagValue')
	@StartFtagValue.setter
	def StartFtagValue(self, value):
		self._set_attribute('startFtagValue', value)

	@property
	def SwitchId(self):
		"""DEPRECATED The Switch ID of the emulated DCE ISIS router.

		Returns:
			number
		"""
		return self._get_attribute('switchId')
	@SwitchId.setter
	def SwitchId(self, value):
		self._set_attribute('switchId', value)

	@property
	def SwitchIdPriority(self):
		"""DEPRECATED The Switch ID priority of the emulated DCE ISIS router.

		Returns:
			number
		"""
		return self._get_attribute('switchIdPriority')
	@SwitchIdPriority.setter
	def SwitchIdPriority(self, value):
		self._set_attribute('switchIdPriority', value)

	@property
	def SystemId(self):
		"""DEPRECATED The neighbor's system ID.

		Returns:
			str
		"""
		return self._get_attribute('systemId')
	@SystemId.setter
	def SystemId(self, value):
		self._set_attribute('systemId', value)

	@property
	def TeEnable(self):
		"""DEPRECATED Enables traffic engineering (TE) on this emulated ISIS router.

		Returns:
			bool
		"""
		return self._get_attribute('teEnable')
	@TeEnable.setter
	def TeEnable(self, value):
		self._set_attribute('teEnable', value)

	@property
	def TeRouterId(self):
		"""DEPRECATED The ID of the simulated router, expressed as an IP address.

		Returns:
			str
		"""
		return self._get_attribute('teRouterId')
	@TeRouterId.setter
	def TeRouterId(self, value):
		self._set_attribute('teRouterId', value)

	@property
	def TrafficGroupId(self):
		"""DEPRECATED Contains the object reference to a traffic group identifier as configured with the trafficGroup object.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)
		"""
		return self._get_attribute('trafficGroupId')
	@TrafficGroupId.setter
	def TrafficGroupId(self, value):
		self._set_attribute('trafficGroupId', value)

	def update(self, AreaAddressList=None, AreaAuthType=None, AreaReceivedPasswordList=None, AreaTransmitPassword=None, BroadcastRootPriority=None, CapabilityRouterId=None, DeviceId=None, DevicePriority=None, DomainAuthType=None, DomainReceivedPasswordList=None, DomainTransmitPassword=None, EnableAttached=None, EnableAutoLoopback=None, EnableDiscardLearnedLsps=None, EnableHelloPadding=None, EnableHitlessRestart=None, EnableHostName=None, EnableIgnoreMtPortCapability=None, EnableIgnoreRecvMd5=None, EnableMtIpv6=None, EnableMtuProbe=None, EnableMultiTopology=None, EnableOverloaded=None, EnablePartitionRepair=None, EnableTrillOam=None, EnableWideMetric=None, Enabled=None, FTagValue=None, FilterIpv4MulticastTlvs=None, FilterIpv6MulticastTlvs=None, FilterLearnedIpv4Prefixes=None, FilterLearnedIpv6Prefixes=None, FilterLearnedRbridges=None, FilterLearnedSpbRbridges=None, FilterLearnedTrillMacUnicast=None, FilterMacMulticastTlvs=None, HostName=None, InterLspMgroupPduBurstGap=None, LspLifeTime=None, LspMaxSize=None, LspMgroupPduMinTransmissionInterval=None, LspRefreshRate=None, MaxAreaAddresses=None, MaxLspMgroupPdusPerBurst=None, NumberOfMtuProbes=None, NumberOfMultiDestinationTrees=None, OriginatingLspBufSize=None, PsnpInterval=None, RestartMode=None, RestartTime=None, RestartVersion=None, StartFtagValue=None, SwitchId=None, SwitchIdPriority=None, SystemId=None, TeEnable=None, TeRouterId=None, TrafficGroupId=None):
		"""Updates a child instance of router on the server.

		Args:
			AreaAddressList (list(str)): The list of area addresses to use.
			AreaAuthType (str(none|password|md5)): Sets up authentication for Level 1 LSPs.
			AreaReceivedPasswordList (list(str)): If areaAuthType is isisAuthTypePassword, then this is a list of passwords that the router will accept on received LSPs.
			AreaTransmitPassword (str): If areaAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted LSPs.
			BroadcastRootPriority (number): The value of the Broadcast Root Priority of a particular DCE ISIS router.
			CapabilityRouterId (str): The IPv4 address format of the Capability Router.
			DeviceId (number): This is a deprecated attribute in DCE ISIS mode.
			DevicePriority (number): This is a deprecated attribute in DCE ISIS mode.
			DomainAuthType (str(none|password|md5)): Sets up authentication for Level 2 LSPs.
			DomainReceivedPasswordList (list(str)): If domainAuthType is isisAuthTypePassword, then this is a list of passwords that the router will accept on received LSPs.
			DomainTransmitPassword (str): If domainAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted LSPs.
			EnableAttached (bool): Indicates that the Attached Flag is set. It indicates that this ISIS router can use L2 routing to reach other areas.
			EnableAutoLoopback (bool): If enabled, loopback addresses are allowed in the generated routes.
			EnableDiscardLearnedLsps (bool): If enabled, LSPs learned from this router's interfaces will be discarded.
			EnableHelloPadding (bool): If true, enables padding of hello messages.
			EnableHitlessRestart (bool): Hitless Restart is enabled for this emulated ISIS router.
			EnableHostName (bool): If true, the given dynamic host name is transmitted in all the packets sent from this router.
			EnableIgnoreMtPortCapability (bool): NOT DEFINED
			EnableIgnoreRecvMd5 (bool): MD5 authentication will be disabled for incoming/received packets.
			EnableMtIpv6 (bool): If checked in L3, emulation type traffic group ID at router level is grayed out and unassigned.
			EnableMtuProbe (bool): NOT DEFINED
			EnableMultiTopology (bool): Enables more than one topology (distribution tree) corresponding to the given R bridge.
			EnableOverloaded (bool): If enabled, the LSP Database Overload Bit is set. It indicates that the LSP database on this router is overloaded and that there is not enough memory to store a received LSP. This router enters the Waiting State and floods an LSP (with LSP number = 0) with the overload bit set, so other routers will not forward ISIS packets to it.
			EnablePartitionRepair (bool): Enables the optional partition repair option specified in ISO/IEC 10589 and RFC 1195 for Level 1 areas.
			EnableTrillOam (bool): NOT DEFINED
			EnableWideMetric (bool): Enables the use of extended reachability (wide) metrics (defined to support TE): 32-bits wide for IP reachability (routes) and 24-bits wide for IS reachability (IS neighbors). If TE is enabled, wide metrics will be enabled automatically. The wide metrics may be used without enabling TE, however.
			Enabled (bool): Enables or disables the simulated router.
			FTagValue (number): This is a deprecated attribute in DCE ISIS mode.
			FilterIpv4MulticastTlvs (bool): If true, retrieves IPv4 Multicast learned information in the DCE ISIS mode.
			FilterIpv6MulticastTlvs (bool): If true, retrieves IPv6 Multicast learned information in the DCE ISIS mode.
			FilterLearnedIpv4Prefixes (bool): If true, retrieves IPv4 Unicast learned information in the ISIS L3 Routing mode.
			FilterLearnedIpv6Prefixes (bool): If true, retrieves IPv6 Unicast learned information in the ISIS L3 Routing mode.
			FilterLearnedRbridges (bool): If true, retrieves RBridges learned information in the DCE ISIS mode.
			FilterLearnedSpbRbridges (bool): NOT DEFINED
			FilterLearnedTrillMacUnicast (bool): NOT DEFINED
			FilterMacMulticastTlvs (bool): If true, retrieves MAC Multicast learned information in the DCE ISIS mode.
			HostName (str): Allows to add a host name to this router.
			InterLspMgroupPduBurstGap (number): Indicates the gap between each LSP MGROUP-PDUs.
			LspLifeTime (number): (in sec) The MaxAge for retaining a learned LSP on this router. The default value is 1,200 sec.
			LspMaxSize (number): (in bytes) The maximum allowable length of an ISIS LSP message. The default is 1,492 bytes.
			LspMgroupPduMinTransmissionInterval (number): Indicates the minimum wait time for each LSP MGROUP-PDU transmission.
			LspRefreshRate (number): (in sec) The rate at which LSPs are resent. The default value is 900 sec.
			MaxAreaAddresses (number): The number of area addresses permitted for this IS area.
			MaxLspMgroupPdusPerBurst (number): Indicates the maximum number of LSP MGROUP-PDUs for each burst.
			NumberOfMtuProbes (number): NOT DEFINED
			NumberOfMultiDestinationTrees (number): The number of Multi-Destination Trees for the emulated DCE ISIS router.
			OriginatingLspBufSize (number): NOT DEFINED
			PsnpInterval (number): The PSPN Interval.
			RestartMode (str(normalRouter|restartingRouter|startingRouter|helperRouter)): If enableHitlessRestart is true, this indicates the mode in which this router is to operate.
			RestartTime (number): Enter the restart time in seconds.
			RestartVersion (str(version3|version4)): If enableHitlessRestart is true, this indicates the version of the draft-ietf-isis-restart-nn document that the router should conform to.
			StartFtagValue (number): The starting FTAG value of the emulated DCE ISIS router.
			SwitchId (number): The Switch ID of the emulated DCE ISIS router.
			SwitchIdPriority (number): The Switch ID priority of the emulated DCE ISIS router.
			SystemId (str): The neighbor's system ID.
			TeEnable (bool): Enables traffic engineering (TE) on this emulated ISIS router.
			TeRouterId (str): The ID of the simulated router, expressed as an IP address.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): Contains the object reference to a traffic group identifier as configured with the trafficGroup object.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, AreaAddressList=None, AreaAuthType=None, AreaReceivedPasswordList=None, AreaTransmitPassword=None, BroadcastRootPriority=None, CapabilityRouterId=None, DeviceId=None, DevicePriority=None, DomainAuthType=None, DomainReceivedPasswordList=None, DomainTransmitPassword=None, EnableAttached=None, EnableAutoLoopback=None, EnableDiscardLearnedLsps=None, EnableHelloPadding=None, EnableHitlessRestart=None, EnableHostName=None, EnableIgnoreMtPortCapability=None, EnableIgnoreRecvMd5=None, EnableMtIpv6=None, EnableMtuProbe=None, EnableMultiTopology=None, EnableOverloaded=None, EnablePartitionRepair=None, EnableTrillOam=None, EnableWideMetric=None, Enabled=None, FTagValue=None, FilterIpv4MulticastTlvs=None, FilterIpv6MulticastTlvs=None, FilterLearnedIpv4Prefixes=None, FilterLearnedIpv6Prefixes=None, FilterLearnedRbridges=None, FilterLearnedSpbRbridges=None, FilterLearnedTrillMacUnicast=None, FilterMacMulticastTlvs=None, HostName=None, InterLspMgroupPduBurstGap=None, LspLifeTime=None, LspMaxSize=None, LspMgroupPduMinTransmissionInterval=None, LspRefreshRate=None, MaxAreaAddresses=None, MaxLspMgroupPdusPerBurst=None, NumberOfMtuProbes=None, NumberOfMultiDestinationTrees=None, OriginatingLspBufSize=None, PsnpInterval=None, RestartMode=None, RestartTime=None, RestartVersion=None, StartFtagValue=None, SwitchId=None, SwitchIdPriority=None, SystemId=None, TeEnable=None, TeRouterId=None, TrafficGroupId=None):
		"""Adds a new router node on the server and retrieves it in this instance.

		Args:
			AreaAddressList (list(str)): The list of area addresses to use.
			AreaAuthType (str(none|password|md5)): Sets up authentication for Level 1 LSPs.
			AreaReceivedPasswordList (list(str)): If areaAuthType is isisAuthTypePassword, then this is a list of passwords that the router will accept on received LSPs.
			AreaTransmitPassword (str): If areaAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted LSPs.
			BroadcastRootPriority (number): The value of the Broadcast Root Priority of a particular DCE ISIS router.
			CapabilityRouterId (str): The IPv4 address format of the Capability Router.
			DeviceId (number): This is a deprecated attribute in DCE ISIS mode.
			DevicePriority (number): This is a deprecated attribute in DCE ISIS mode.
			DomainAuthType (str(none|password|md5)): Sets up authentication for Level 2 LSPs.
			DomainReceivedPasswordList (list(str)): If domainAuthType is isisAuthTypePassword, then this is a list of passwords that the router will accept on received LSPs.
			DomainTransmitPassword (str): If domainAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted LSPs.
			EnableAttached (bool): Indicates that the Attached Flag is set. It indicates that this ISIS router can use L2 routing to reach other areas.
			EnableAutoLoopback (bool): If enabled, loopback addresses are allowed in the generated routes.
			EnableDiscardLearnedLsps (bool): If enabled, LSPs learned from this router's interfaces will be discarded.
			EnableHelloPadding (bool): If true, enables padding of hello messages.
			EnableHitlessRestart (bool): Hitless Restart is enabled for this emulated ISIS router.
			EnableHostName (bool): If true, the given dynamic host name is transmitted in all the packets sent from this router.
			EnableIgnoreMtPortCapability (bool): NOT DEFINED
			EnableIgnoreRecvMd5 (bool): MD5 authentication will be disabled for incoming/received packets.
			EnableMtIpv6 (bool): If checked in L3, emulation type traffic group ID at router level is grayed out and unassigned.
			EnableMtuProbe (bool): NOT DEFINED
			EnableMultiTopology (bool): Enables more than one topology (distribution tree) corresponding to the given R bridge.
			EnableOverloaded (bool): If enabled, the LSP Database Overload Bit is set. It indicates that the LSP database on this router is overloaded and that there is not enough memory to store a received LSP. This router enters the Waiting State and floods an LSP (with LSP number = 0) with the overload bit set, so other routers will not forward ISIS packets to it.
			EnablePartitionRepair (bool): Enables the optional partition repair option specified in ISO/IEC 10589 and RFC 1195 for Level 1 areas.
			EnableTrillOam (bool): NOT DEFINED
			EnableWideMetric (bool): Enables the use of extended reachability (wide) metrics (defined to support TE): 32-bits wide for IP reachability (routes) and 24-bits wide for IS reachability (IS neighbors). If TE is enabled, wide metrics will be enabled automatically. The wide metrics may be used without enabling TE, however.
			Enabled (bool): Enables or disables the simulated router.
			FTagValue (number): This is a deprecated attribute in DCE ISIS mode.
			FilterIpv4MulticastTlvs (bool): If true, retrieves IPv4 Multicast learned information in the DCE ISIS mode.
			FilterIpv6MulticastTlvs (bool): If true, retrieves IPv6 Multicast learned information in the DCE ISIS mode.
			FilterLearnedIpv4Prefixes (bool): If true, retrieves IPv4 Unicast learned information in the ISIS L3 Routing mode.
			FilterLearnedIpv6Prefixes (bool): If true, retrieves IPv6 Unicast learned information in the ISIS L3 Routing mode.
			FilterLearnedRbridges (bool): If true, retrieves RBridges learned information in the DCE ISIS mode.
			FilterLearnedSpbRbridges (bool): NOT DEFINED
			FilterLearnedTrillMacUnicast (bool): NOT DEFINED
			FilterMacMulticastTlvs (bool): If true, retrieves MAC Multicast learned information in the DCE ISIS mode.
			HostName (str): Allows to add a host name to this router.
			InterLspMgroupPduBurstGap (number): Indicates the gap between each LSP MGROUP-PDUs.
			LspLifeTime (number): (in sec) The MaxAge for retaining a learned LSP on this router. The default value is 1,200 sec.
			LspMaxSize (number): (in bytes) The maximum allowable length of an ISIS LSP message. The default is 1,492 bytes.
			LspMgroupPduMinTransmissionInterval (number): Indicates the minimum wait time for each LSP MGROUP-PDU transmission.
			LspRefreshRate (number): (in sec) The rate at which LSPs are resent. The default value is 900 sec.
			MaxAreaAddresses (number): The number of area addresses permitted for this IS area.
			MaxLspMgroupPdusPerBurst (number): Indicates the maximum number of LSP MGROUP-PDUs for each burst.
			NumberOfMtuProbes (number): NOT DEFINED
			NumberOfMultiDestinationTrees (number): The number of Multi-Destination Trees for the emulated DCE ISIS router.
			OriginatingLspBufSize (number): NOT DEFINED
			PsnpInterval (number): The PSPN Interval.
			RestartMode (str(normalRouter|restartingRouter|startingRouter|helperRouter)): If enableHitlessRestart is true, this indicates the mode in which this router is to operate.
			RestartTime (number): Enter the restart time in seconds.
			RestartVersion (str(version3|version4)): If enableHitlessRestart is true, this indicates the version of the draft-ietf-isis-restart-nn document that the router should conform to.
			StartFtagValue (number): The starting FTAG value of the emulated DCE ISIS router.
			SwitchId (number): The Switch ID of the emulated DCE ISIS router.
			SwitchIdPriority (number): The Switch ID priority of the emulated DCE ISIS router.
			SystemId (str): The neighbor's system ID.
			TeEnable (bool): Enables traffic engineering (TE) on this emulated ISIS router.
			TeRouterId (str): The ID of the simulated router, expressed as an IP address.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): Contains the object reference to a traffic group identifier as configured with the trafficGroup object.

		Returns:
			self: This instance with all currently retrieved router data using find and the newly added router data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the router data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, AreaAddressList=None, AreaAuthType=None, AreaReceivedPasswordList=None, AreaTransmitPassword=None, BroadcastRootPriority=None, CapabilityRouterId=None, DeviceId=None, DevicePriority=None, DomainAuthType=None, DomainReceivedPasswordList=None, DomainTransmitPassword=None, EnableAttached=None, EnableAutoLoopback=None, EnableDiscardLearnedLsps=None, EnableHelloPadding=None, EnableHitlessRestart=None, EnableHostName=None, EnableIgnoreMtPortCapability=None, EnableIgnoreRecvMd5=None, EnableMtIpv6=None, EnableMtuProbe=None, EnableMultiTopology=None, EnableOverloaded=None, EnablePartitionRepair=None, EnableTrillOam=None, EnableWideMetric=None, Enabled=None, FTagValue=None, FilterIpv4MulticastTlvs=None, FilterIpv6MulticastTlvs=None, FilterLearnedIpv4Prefixes=None, FilterLearnedIpv6Prefixes=None, FilterLearnedRbridges=None, FilterLearnedSpbRbridges=None, FilterLearnedTrillMacUnicast=None, FilterMacMulticastTlvs=None, HostName=None, InterLspMgroupPduBurstGap=None, LspLifeTime=None, LspMaxSize=None, LspMgroupPduMinTransmissionInterval=None, LspRefreshRate=None, MaxAreaAddresses=None, MaxLspMgroupPdusPerBurst=None, NumberOfMtuProbes=None, NumberOfMultiDestinationTrees=None, OriginatingLspBufSize=None, PsnpInterval=None, RestartMode=None, RestartTime=None, RestartVersion=None, StartFtagValue=None, SwitchId=None, SwitchIdPriority=None, SystemId=None, TeEnable=None, TeRouterId=None, TrafficGroupId=None):
		"""Finds and retrieves router data from the server.

		All named parameters support regex and can be used to selectively retrieve router data from the server.
		By default the find method takes no parameters and will retrieve all router data from the server.

		Args:
			AreaAddressList (list(str)): The list of area addresses to use.
			AreaAuthType (str(none|password|md5)): Sets up authentication for Level 1 LSPs.
			AreaReceivedPasswordList (list(str)): If areaAuthType is isisAuthTypePassword, then this is a list of passwords that the router will accept on received LSPs.
			AreaTransmitPassword (str): If areaAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted LSPs.
			BroadcastRootPriority (number): The value of the Broadcast Root Priority of a particular DCE ISIS router.
			CapabilityRouterId (str): The IPv4 address format of the Capability Router.
			DeviceId (number): This is a deprecated attribute in DCE ISIS mode.
			DevicePriority (number): This is a deprecated attribute in DCE ISIS mode.
			DomainAuthType (str(none|password|md5)): Sets up authentication for Level 2 LSPs.
			DomainReceivedPasswordList (list(str)): If domainAuthType is isisAuthTypePassword, then this is a list of passwords that the router will accept on received LSPs.
			DomainTransmitPassword (str): If domainAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted LSPs.
			EnableAttached (bool): Indicates that the Attached Flag is set. It indicates that this ISIS router can use L2 routing to reach other areas.
			EnableAutoLoopback (bool): If enabled, loopback addresses are allowed in the generated routes.
			EnableDiscardLearnedLsps (bool): If enabled, LSPs learned from this router's interfaces will be discarded.
			EnableHelloPadding (bool): If true, enables padding of hello messages.
			EnableHitlessRestart (bool): Hitless Restart is enabled for this emulated ISIS router.
			EnableHostName (bool): If true, the given dynamic host name is transmitted in all the packets sent from this router.
			EnableIgnoreMtPortCapability (bool): NOT DEFINED
			EnableIgnoreRecvMd5 (bool): MD5 authentication will be disabled for incoming/received packets.
			EnableMtIpv6 (bool): If checked in L3, emulation type traffic group ID at router level is grayed out and unassigned.
			EnableMtuProbe (bool): NOT DEFINED
			EnableMultiTopology (bool): Enables more than one topology (distribution tree) corresponding to the given R bridge.
			EnableOverloaded (bool): If enabled, the LSP Database Overload Bit is set. It indicates that the LSP database on this router is overloaded and that there is not enough memory to store a received LSP. This router enters the Waiting State and floods an LSP (with LSP number = 0) with the overload bit set, so other routers will not forward ISIS packets to it.
			EnablePartitionRepair (bool): Enables the optional partition repair option specified in ISO/IEC 10589 and RFC 1195 for Level 1 areas.
			EnableTrillOam (bool): NOT DEFINED
			EnableWideMetric (bool): Enables the use of extended reachability (wide) metrics (defined to support TE): 32-bits wide for IP reachability (routes) and 24-bits wide for IS reachability (IS neighbors). If TE is enabled, wide metrics will be enabled automatically. The wide metrics may be used without enabling TE, however.
			Enabled (bool): Enables or disables the simulated router.
			FTagValue (number): This is a deprecated attribute in DCE ISIS mode.
			FilterIpv4MulticastTlvs (bool): If true, retrieves IPv4 Multicast learned information in the DCE ISIS mode.
			FilterIpv6MulticastTlvs (bool): If true, retrieves IPv6 Multicast learned information in the DCE ISIS mode.
			FilterLearnedIpv4Prefixes (bool): If true, retrieves IPv4 Unicast learned information in the ISIS L3 Routing mode.
			FilterLearnedIpv6Prefixes (bool): If true, retrieves IPv6 Unicast learned information in the ISIS L3 Routing mode.
			FilterLearnedRbridges (bool): If true, retrieves RBridges learned information in the DCE ISIS mode.
			FilterLearnedSpbRbridges (bool): NOT DEFINED
			FilterLearnedTrillMacUnicast (bool): NOT DEFINED
			FilterMacMulticastTlvs (bool): If true, retrieves MAC Multicast learned information in the DCE ISIS mode.
			HostName (str): Allows to add a host name to this router.
			InterLspMgroupPduBurstGap (number): Indicates the gap between each LSP MGROUP-PDUs.
			LspLifeTime (number): (in sec) The MaxAge for retaining a learned LSP on this router. The default value is 1,200 sec.
			LspMaxSize (number): (in bytes) The maximum allowable length of an ISIS LSP message. The default is 1,492 bytes.
			LspMgroupPduMinTransmissionInterval (number): Indicates the minimum wait time for each LSP MGROUP-PDU transmission.
			LspRefreshRate (number): (in sec) The rate at which LSPs are resent. The default value is 900 sec.
			MaxAreaAddresses (number): The number of area addresses permitted for this IS area.
			MaxLspMgroupPdusPerBurst (number): Indicates the maximum number of LSP MGROUP-PDUs for each burst.
			NumberOfMtuProbes (number): NOT DEFINED
			NumberOfMultiDestinationTrees (number): The number of Multi-Destination Trees for the emulated DCE ISIS router.
			OriginatingLspBufSize (number): NOT DEFINED
			PsnpInterval (number): The PSPN Interval.
			RestartMode (str(normalRouter|restartingRouter|startingRouter|helperRouter)): If enableHitlessRestart is true, this indicates the mode in which this router is to operate.
			RestartTime (number): Enter the restart time in seconds.
			RestartVersion (str(version3|version4)): If enableHitlessRestart is true, this indicates the version of the draft-ietf-isis-restart-nn document that the router should conform to.
			StartFtagValue (number): The starting FTAG value of the emulated DCE ISIS router.
			SwitchId (number): The Switch ID of the emulated DCE ISIS router.
			SwitchIdPriority (number): The Switch ID priority of the emulated DCE ISIS router.
			SystemId (str): The neighbor's system ID.
			TeEnable (bool): Enables traffic engineering (TE) on this emulated ISIS router.
			TeRouterId (str): The ID of the simulated router, expressed as an IP address.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): Contains the object reference to a traffic group identifier as configured with the trafficGroup object.

		Returns:
			self: This instance with matching router data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of router data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the router data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def RefreshLearnedInformation(self):
		"""Executes the refreshLearnedInformation operation on the server.

		This option refreshes the learned information of ISIS router.

			Returns:
				bool: Boolean.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshLearnedInformation', payload=payload, response_object=None)

	def SendTrillOamPing(self):
		"""Executes the sendTrillOamPing operation on the server.

		This option will send trill OAM ping.

			Returns:
				bool: Boolean.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendTrillOamPing', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class ReportGeneration(Base):
	"""The ReportGeneration class encapsulates a required reportGeneration node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the ReportGeneration property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'reportGeneration'

	def __init__(self, parent):
		super(ReportGeneration, self).__init__(parent)

	@property
	def OutputFile(self):
		"""Signifies the output file

		Returns:
			str
		"""
		return self._get_attribute('OutputFile')
	@OutputFile.setter
	def OutputFile(self, value):
		self._set_attribute('OutputFile', value)

	@property
	def OutputType(self):
		"""Signifies the output type

		Returns:
			str(Html|Pdf)
		"""
		return self._get_attribute('OutputType')
	@OutputType.setter
	def OutputType(self, value):
		self._set_attribute('OutputType', value)

	@property
	def Template(self):
		"""Signifies the template for IxReporter

		Returns:
			str
		"""
		return self._get_attribute('Template')
	@Template.setter
	def Template(self, value):
		self._set_attribute('Template', value)

	@property
	def TestRunId(self):
		"""Signifies the identifier for the test run

		Returns:
			number
		"""
		return self._get_attribute('TestRunId')
	@TestRunId.setter
	def TestRunId(self, value):
		self._set_attribute('TestRunId', value)

	def update(self, OutputFile=None, OutputType=None, Template=None, TestRunId=None):
		"""Updates a child instance of reportGeneration on the server.

		Args:
			OutputFile (str): Signifies the output file
			OutputType (str(Html|Pdf)): Signifies the output type
			Template (str): Signifies the template for IxReporter
			TestRunId (number): Signifies the identifier for the test run

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Start(self):
		"""Executes the start operation on the server.

		NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('start', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TestConfig(Base):
	"""The TestConfig class encapsulates a required testConfig node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TestConfig property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'testConfig'

	def __init__(self, parent):
		super(TestConfig, self).__init__(parent)

	@property
	def ApplyMode(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('applyMode')
	@ApplyMode.setter
	def ApplyMode(self, value):
		self._set_attribute('applyMode', value)

	@property
	def AssignGroupType(self):
		"""Assigns the group type.

		Returns:
			str(accumulated|distributed)
		"""
		return self._get_attribute('assignGroupType')
	@AssignGroupType.setter
	def AssignGroupType(self, value):
		self._set_attribute('assignGroupType', value)

	@property
	def BidirectionalOptionEnabled(self):
		"""If true, enables the bidirectional option.

		Returns:
			bool
		"""
		return self._get_attribute('bidirectionalOptionEnabled')
	@BidirectionalOptionEnabled.setter
	def BidirectionalOptionEnabled(self, value):
		self._set_attribute('bidirectionalOptionEnabled', value)

	@property
	def BinaryBackoff(self):
		"""Specifies the percentage of binary backoff.

		Returns:
			number
		"""
		return self._get_attribute('binaryBackoff')
	@BinaryBackoff.setter
	def BinaryBackoff(self, value):
		self._set_attribute('binaryBackoff', value)

	@property
	def BinaryResolution(self):
		"""Specifies the resolution of the iteration. The difference between the real rate transmission in two consecutive iterations, expressed as a percentage, is compared with the resolution value. When the difference is smaller than the value specified for the resolution, the test stops.

		Returns:
			number
		"""
		return self._get_attribute('binaryResolution')
	@BinaryResolution.setter
	def BinaryResolution(self, value):
		self._set_attribute('binaryResolution', value)

	@property
	def CountRandomFrameSize(self):
		"""The count of the random frame size to be sent.

		Returns:
			number
		"""
		return self._get_attribute('countRandomFrameSize')
	@CountRandomFrameSize.setter
	def CountRandomFrameSize(self, value):
		self._set_attribute('countRandomFrameSize', value)

	@property
	def DelayAfterTransmit(self):
		"""Specifies the amount of delay after every transmit.

		Returns:
			number
		"""
		return self._get_attribute('delayAfterTransmit')
	@DelayAfterTransmit.setter
	def DelayAfterTransmit(self, value):
		self._set_attribute('delayAfterTransmit', value)

	@property
	def DummyTrafficId(self):
		"""The id of the monitor traffic item

		Returns:
			str
		"""
		return self._get_attribute('dummyTrafficId')
	@DummyTrafficId.setter
	def DummyTrafficId(self, value):
		self._set_attribute('dummyTrafficId', value)

	@property
	def Duration(self):
		"""The duration of the test in hours, minutes, or seconds, which is used to calculate the number of frames to transmit.

		Returns:
			number
		"""
		return self._get_attribute('duration')
	@Duration.setter
	def Duration(self, value):
		self._set_attribute('duration', value)

	@property
	def EnableLayer1Rate(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableLayer1Rate')
	@EnableLayer1Rate.setter
	def EnableLayer1Rate(self, value):
		self._set_attribute('enableLayer1Rate', value)

	@property
	def EnableLeaveGroup(self):
		"""If true, the leave group is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enableLeaveGroup')
	@EnableLeaveGroup.setter
	def EnableLeaveGroup(self, value):
		self._set_attribute('enableLeaveGroup', value)

	@property
	def EnableMinFrameSize(self):
		"""If true, enables minimum frame size.

		Returns:
			bool
		"""
		return self._get_attribute('enableMinFrameSize')
	@EnableMinFrameSize.setter
	def EnableMinFrameSize(self, value):
		self._set_attribute('enableMinFrameSize', value)

	@property
	def EnableMulticastQuerier(self):
		"""Enable Multicast Querier Settings

		Returns:
			bool
		"""
		return self._get_attribute('enableMulticastQuerier')
	@EnableMulticastQuerier.setter
	def EnableMulticastQuerier(self, value):
		self._set_attribute('enableMulticastQuerier', value)

	@property
	def EnableOldStatsForReef(self):
		"""If true, enables the old statistics for Reef.

		Returns:
			bool
		"""
		return self._get_attribute('enableOldStatsForReef')
	@EnableOldStatsForReef.setter
	def EnableOldStatsForReef(self, value):
		self._set_attribute('enableOldStatsForReef', value)

	@property
	def FloodedFramesEnabled(self):
		"""If true, it enables the flooded frames statistics

		Returns:
			bool
		"""
		return self._get_attribute('floodedFramesEnabled')
	@FloodedFramesEnabled.setter
	def FloodedFramesEnabled(self, value):
		self._set_attribute('floodedFramesEnabled', value)

	@property
	def FloodedFramesProcessing(self):
		"""Flooded Frames Processing

		Returns:
			bool
		"""
		return self._get_attribute('floodedFramesProcessing')
	@FloodedFramesProcessing.setter
	def FloodedFramesProcessing(self, value):
		self._set_attribute('floodedFramesProcessing', value)

	@property
	def FloodedFramesTemp(self):
		"""Flooded Frames Temp

		Returns:
			str
		"""
		return self._get_attribute('floodedFramesTemp')
	@FloodedFramesTemp.setter
	def FloodedFramesTemp(self, value):
		self._set_attribute('floodedFramesTemp', value)

	@property
	def ForceRegenerate(self):
		"""If true, enables force regenerate.

		Returns:
			bool
		"""
		return self._get_attribute('forceRegenerate')
	@ForceRegenerate.setter
	def ForceRegenerate(self, value):
		self._set_attribute('forceRegenerate', value)

	@property
	def FrameSizeMode(self):
		"""This attribute is the frame size mode for the Quad Gaussian.

		Returns:
			str(custom|customlist|increment|random)
		"""
		return self._get_attribute('frameSizeMode')
	@FrameSizeMode.setter
	def FrameSizeMode(self, value):
		self._set_attribute('frameSizeMode', value)

	@property
	def FramesizeList(self):
		"""The list of the available frame sizes.

		Returns:
			list(str)
		"""
		return self._get_attribute('framesizeList')
	@FramesizeList.setter
	def FramesizeList(self, value):
		self._set_attribute('framesizeList', value)

	@property
	def Gap(self):
		"""The gap in transmission of frames.

		Returns:
			number
		"""
		return self._get_attribute('gap')
	@Gap.setter
	def Gap(self, value):
		self._set_attribute('gap', value)

	@property
	def GroupCapacityGreaterThan(self):
		"""Indicates the value by which the group capacity is greater than.

		Returns:
			number
		"""
		return self._get_attribute('groupCapacityGreaterThan')
	@GroupCapacityGreaterThan.setter
	def GroupCapacityGreaterThan(self, value):
		self._set_attribute('groupCapacityGreaterThan', value)

	@property
	def GroupDistributionType(self):
		"""Indicates the group distribution type.

		Returns:
			str(acrossHosts|acrossPorts)
		"""
		return self._get_attribute('groupDistributionType')
	@GroupDistributionType.setter
	def GroupDistributionType(self, value):
		self._set_attribute('groupDistributionType', value)

	@property
	def IgmpV1Timeout(self):
		"""It signifies the timeout of version 1 of IGMP.

		Returns:
			number
		"""
		return self._get_attribute('igmpV1Timeout')
	@IgmpV1Timeout.setter
	def IgmpV1Timeout(self, value):
		self._set_attribute('igmpV1Timeout', value)

	@property
	def IgmpVersion(self):
		"""The igmp version.

		Returns:
			number
		"""
		return self._get_attribute('igmpVersion')
	@IgmpVersion.setter
	def IgmpVersion(self, value):
		self._set_attribute('igmpVersion', value)

	@property
	def Igmpv3MessageType(self):
		"""It gives details about the igmpv3 message type in the test configuration

		Returns:
			str(exclude|include)
		"""
		return self._get_attribute('igmpv3MessageType')
	@Igmpv3MessageType.setter
	def Igmpv3MessageType(self, value):
		self._set_attribute('igmpv3MessageType', value)

	@property
	def Igmpv3SourceAddrList(self):
		"""It gives details about the igmpv3 source address list in the test configuration

		Returns:
			str
		"""
		return self._get_attribute('igmpv3SourceAddrList')
	@Igmpv3SourceAddrList.setter
	def Igmpv3SourceAddrList(self, value):
		self._set_attribute('igmpv3SourceAddrList', value)

	@property
	def IncrAddresses(self):
		"""If true, the MAC address is incremented.

		Returns:
			number
		"""
		return self._get_attribute('incrAddresses')
	@IncrAddresses.setter
	def IncrAddresses(self, value):
		self._set_attribute('incrAddresses', value)

	@property
	def IncrementLoadUnit(self):
		"""The incremental value of the load unit.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('incrementLoadUnit')
	@IncrementLoadUnit.setter
	def IncrementLoadUnit(self, value):
		self._set_attribute('incrementLoadUnit', value)

	@property
	def InitialBinaryLoadIntegerValues(self):
		"""Initial Binary Load Integer Values

		Returns:
			number
		"""
		return self._get_attribute('initialBinaryLoadIntegerValues')
	@InitialBinaryLoadIntegerValues.setter
	def InitialBinaryLoadIntegerValues(self, value):
		self._set_attribute('initialBinaryLoadIntegerValues', value)

	@property
	def Ipv4Address(self):
		"""The selected IPv4 address.

		Returns:
			str
		"""
		return self._get_attribute('ipv4Address')
	@Ipv4Address.setter
	def Ipv4Address(self, value):
		self._set_attribute('ipv4Address', value)

	@property
	def Ipv6Address(self):
		"""It signifies the IP address for version 6.

		Returns:
			str
		"""
		return self._get_attribute('ipv6Address')
	@Ipv6Address.setter
	def Ipv6Address(self, value):
		self._set_attribute('ipv6Address', value)

	@property
	def IsIPv6(self):
		"""If true, indicates an IPv6 address.

		Returns:
			str
		"""
		return self._get_attribute('isIPv6')
	@IsIPv6.setter
	def IsIPv6(self, value):
		self._set_attribute('isIPv6', value)

	@property
	def IsMulticastAutomaticFrameData(self):
		"""If true, indicates a multicast automatic frame data.

		Returns:
			str
		"""
		return self._get_attribute('isMulticastAutomaticFrameData')
	@IsMulticastAutomaticFrameData.setter
	def IsMulticastAutomaticFrameData(self, value):
		self._set_attribute('isMulticastAutomaticFrameData', value)

	@property
	def JoinLeaveMultiplier(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('joinLeaveMultiplier')
	@JoinLeaveMultiplier.setter
	def JoinLeaveMultiplier(self, value):
		self._set_attribute('joinLeaveMultiplier', value)

	@property
	def JoinLeaveRate(self):
		"""The leave rate.

		Returns:
			number
		"""
		return self._get_attribute('joinLeaveRate')
	@JoinLeaveRate.setter
	def JoinLeaveRate(self, value):
		self._set_attribute('joinLeaveRate', value)

	@property
	def JoinLeaveWaitTime(self):
		"""The wait time for the leave.

		Returns:
			number
		"""
		return self._get_attribute('joinLeaveWaitTime')
	@JoinLeaveWaitTime.setter
	def JoinLeaveWaitTime(self, value):
		self._set_attribute('joinLeaveWaitTime', value)

	@property
	def LoadInitialRate(self):
		"""The initial rate of the load.

		Returns:
			number
		"""
		return self._get_attribute('loadInitialRate')
	@LoadInitialRate.setter
	def LoadInitialRate(self, value):
		self._set_attribute('loadInitialRate', value)

	@property
	def LoadType(self):
		"""The type of load used to modify the variable parameter value.

		Returns:
			str(binary|step)
		"""
		return self._get_attribute('loadType')
	@LoadType.setter
	def LoadType(self, value):
		self._set_attribute('loadType', value)

	@property
	def MapType(self):
		"""The mapping type.

		Returns:
			str
		"""
		return self._get_attribute('mapType')
	@MapType.setter
	def MapType(self, value):
		self._set_attribute('mapType', value)

	@property
	def MaxBinaryLoadIntegerValue(self):
		"""Max Binary Load Integer Value

		Returns:
			number
		"""
		return self._get_attribute('maxBinaryLoadIntegerValue')
	@MaxBinaryLoadIntegerValue.setter
	def MaxBinaryLoadIntegerValue(self, value):
		self._set_attribute('maxBinaryLoadIntegerValue', value)

	@property
	def MaxIncrementFrameSize(self):
		"""The maximum increment value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('maxIncrementFrameSize')
	@MaxIncrementFrameSize.setter
	def MaxIncrementFrameSize(self, value):
		self._set_attribute('maxIncrementFrameSize', value)

	@property
	def MaxRandomFrameSize(self):
		"""The maximum random frame size to be sent.

		Returns:
			number
		"""
		return self._get_attribute('maxRandomFrameSize')
	@MaxRandomFrameSize.setter
	def MaxRandomFrameSize(self, value):
		self._set_attribute('maxRandomFrameSize', value)

	@property
	def MinBinaryLoadIntegerValues(self):
		"""Min Binary Load Integer Values

		Returns:
			number
		"""
		return self._get_attribute('minBinaryLoadIntegerValues')
	@MinBinaryLoadIntegerValues.setter
	def MinBinaryLoadIntegerValues(self, value):
		self._set_attribute('minBinaryLoadIntegerValues', value)

	@property
	def MinIncrementFrameSize(self):
		"""The minimum increment value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('minIncrementFrameSize')
	@MinIncrementFrameSize.setter
	def MinIncrementFrameSize(self, value):
		self._set_attribute('minIncrementFrameSize', value)

	@property
	def MinRandomFrameSize(self):
		"""The minimum random frame size to be sent.

		Returns:
			number
		"""
		return self._get_attribute('minRandomFrameSize')
	@MinRandomFrameSize.setter
	def MinRandomFrameSize(self, value):
		self._set_attribute('minRandomFrameSize', value)

	@property
	def MldVersion(self):
		"""The version of the MLD messages.

		Returns:
			number
		"""
		return self._get_attribute('mldVersion')
	@MldVersion.setter
	def MldVersion(self, value):
		self._set_attribute('mldVersion', value)

	@property
	def MulticastProtocolUsed(self):
		"""The multicast protocol that is used.

		Returns:
			str
		"""
		return self._get_attribute('multicastProtocolUsed')
	@MulticastProtocolUsed.setter
	def MulticastProtocolUsed(self, value):
		self._set_attribute('multicastProtocolUsed', value)

	@property
	def NumAddresses(self):
		"""The number address.

		Returns:
			number
		"""
		return self._get_attribute('numAddresses')
	@NumAddresses.setter
	def NumAddresses(self, value):
		self._set_attribute('numAddresses', value)

	@property
	def Numtrials(self):
		"""Defines how many times each frame size will be tested.

		Returns:
			number
		"""
		return self._get_attribute('numtrials')
	@Numtrials.setter
	def Numtrials(self, value):
		self._set_attribute('numtrials', value)

	@property
	def PortDelayEnabled(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('portDelayEnabled')
	@PortDelayEnabled.setter
	def PortDelayEnabled(self, value):
		self._set_attribute('portDelayEnabled', value)

	@property
	def PortDelayUnit(self):
		"""Sets the port delay unit in which it will be measured

		Returns:
			str(bytes|nanoseconds)
		"""
		return self._get_attribute('portDelayUnit')
	@PortDelayUnit.setter
	def PortDelayUnit(self, value):
		self._set_attribute('portDelayUnit', value)

	@property
	def PortDelayValue(self):
		"""Sets the port delay value

		Returns:
			number
		"""
		return self._get_attribute('portDelayValue')
	@PortDelayValue.setter
	def PortDelayValue(self, value):
		self._set_attribute('portDelayValue', value)

	@property
	def ProtocolItem(self):
		"""Protocol Items

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])
		"""
		return self._get_attribute('protocolItem')
	@ProtocolItem.setter
	def ProtocolItem(self, value):
		self._set_attribute('protocolItem', value)

	@property
	def ReportTputRateUnit(self):
		"""Report identifying the unit for measuring the throughput rate in frames per second.

		Returns:
			str(gbps|gBps|kbps|kBps|mbps|mBps)
		"""
		return self._get_attribute('reportTputRateUnit')
	@ReportTputRateUnit.setter
	def ReportTputRateUnit(self, value):
		self._set_attribute('reportTputRateUnit', value)

	@property
	def RouterAlert(self):
		"""If enabled, it alerts the router.

		Returns:
			bool
		"""
		return self._get_attribute('routerAlert')
	@RouterAlert.setter
	def RouterAlert(self, value):
		self._set_attribute('routerAlert', value)

	@property
	def ShowDetailedBinaryResults(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('showDetailedBinaryResults')
	@ShowDetailedBinaryResults.setter
	def ShowDetailedBinaryResults(self, value):
		self._set_attribute('showDetailedBinaryResults', value)

	@property
	def StepIncrementFrameSize(self):
		"""The step increment value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('stepIncrementFrameSize')
	@StepIncrementFrameSize.setter
	def StepIncrementFrameSize(self, value):
		self._set_attribute('stepIncrementFrameSize', value)

	@property
	def SupportedTrafficTypes(self):
		"""The traffic types supported.

		Returns:
			str
		"""
		return self._get_attribute('supportedTrafficTypes')
	@SupportedTrafficTypes.setter
	def SupportedTrafficTypes(self, value):
		self._set_attribute('supportedTrafficTypes', value)

	@property
	def TestTrafficType(self):
		"""It signifies the test traffic type value.

		Returns:
			str
		"""
		return self._get_attribute('testTrafficType')
	@TestTrafficType.setter
	def TestTrafficType(self, value):
		self._set_attribute('testTrafficType', value)

	@property
	def TxDelay(self):
		"""The delay in transmission.

		Returns:
			number
		"""
		return self._get_attribute('txDelay')
	@TxDelay.setter
	def TxDelay(self, value):
		self._set_attribute('txDelay', value)

	def update(self, ApplyMode=None, AssignGroupType=None, BidirectionalOptionEnabled=None, BinaryBackoff=None, BinaryResolution=None, CountRandomFrameSize=None, DelayAfterTransmit=None, DummyTrafficId=None, Duration=None, EnableLayer1Rate=None, EnableLeaveGroup=None, EnableMinFrameSize=None, EnableMulticastQuerier=None, EnableOldStatsForReef=None, FloodedFramesEnabled=None, FloodedFramesProcessing=None, FloodedFramesTemp=None, ForceRegenerate=None, FrameSizeMode=None, FramesizeList=None, Gap=None, GroupCapacityGreaterThan=None, GroupDistributionType=None, IgmpV1Timeout=None, IgmpVersion=None, Igmpv3MessageType=None, Igmpv3SourceAddrList=None, IncrAddresses=None, IncrementLoadUnit=None, InitialBinaryLoadIntegerValues=None, Ipv4Address=None, Ipv6Address=None, IsIPv6=None, IsMulticastAutomaticFrameData=None, JoinLeaveMultiplier=None, JoinLeaveRate=None, JoinLeaveWaitTime=None, LoadInitialRate=None, LoadType=None, MapType=None, MaxBinaryLoadIntegerValue=None, MaxIncrementFrameSize=None, MaxRandomFrameSize=None, MinBinaryLoadIntegerValues=None, MinIncrementFrameSize=None, MinRandomFrameSize=None, MldVersion=None, MulticastProtocolUsed=None, NumAddresses=None, Numtrials=None, PortDelayEnabled=None, PortDelayUnit=None, PortDelayValue=None, ProtocolItem=None, ReportTputRateUnit=None, RouterAlert=None, ShowDetailedBinaryResults=None, StepIncrementFrameSize=None, SupportedTrafficTypes=None, TestTrafficType=None, TxDelay=None):
		"""Updates a child instance of testConfig on the server.

		Args:
			ApplyMode (str): NOT DEFINED
			AssignGroupType (str(accumulated|distributed)): Assigns the group type.
			BidirectionalOptionEnabled (bool): If true, enables the bidirectional option.
			BinaryBackoff (number): Specifies the percentage of binary backoff.
			BinaryResolution (number): Specifies the resolution of the iteration. The difference between the real rate transmission in two consecutive iterations, expressed as a percentage, is compared with the resolution value. When the difference is smaller than the value specified for the resolution, the test stops.
			CountRandomFrameSize (number): The count of the random frame size to be sent.
			DelayAfterTransmit (number): Specifies the amount of delay after every transmit.
			DummyTrafficId (str): The id of the monitor traffic item
			Duration (number): The duration of the test in hours, minutes, or seconds, which is used to calculate the number of frames to transmit.
			EnableLayer1Rate (bool): NOT DEFINED
			EnableLeaveGroup (bool): If true, the leave group is enabled.
			EnableMinFrameSize (bool): If true, enables minimum frame size.
			EnableMulticastQuerier (bool): Enable Multicast Querier Settings
			EnableOldStatsForReef (bool): If true, enables the old statistics for Reef.
			FloodedFramesEnabled (bool): If true, it enables the flooded frames statistics
			FloodedFramesProcessing (bool): Flooded Frames Processing
			FloodedFramesTemp (str): Flooded Frames Temp
			ForceRegenerate (bool): If true, enables force regenerate.
			FrameSizeMode (str(custom|customlist|increment|random)): This attribute is the frame size mode for the Quad Gaussian.
			FramesizeList (list(str)): The list of the available frame sizes.
			Gap (number): The gap in transmission of frames.
			GroupCapacityGreaterThan (number): Indicates the value by which the group capacity is greater than.
			GroupDistributionType (str(acrossHosts|acrossPorts)): Indicates the group distribution type.
			IgmpV1Timeout (number): It signifies the timeout of version 1 of IGMP.
			IgmpVersion (number): The igmp version.
			Igmpv3MessageType (str(exclude|include)): It gives details about the igmpv3 message type in the test configuration
			Igmpv3SourceAddrList (str): It gives details about the igmpv3 source address list in the test configuration
			IncrAddresses (number): If true, the MAC address is incremented.
			IncrementLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): The incremental value of the load unit.
			InitialBinaryLoadIntegerValues (number): Initial Binary Load Integer Values
			Ipv4Address (str): The selected IPv4 address.
			Ipv6Address (str): It signifies the IP address for version 6.
			IsIPv6 (str): If true, indicates an IPv6 address.
			IsMulticastAutomaticFrameData (str): If true, indicates a multicast automatic frame data.
			JoinLeaveMultiplier (number): NOT DEFINED
			JoinLeaveRate (number): The leave rate.
			JoinLeaveWaitTime (number): The wait time for the leave.
			LoadInitialRate (number): The initial rate of the load.
			LoadType (str(binary|step)): The type of load used to modify the variable parameter value.
			MapType (str): The mapping type.
			MaxBinaryLoadIntegerValue (number): Max Binary Load Integer Value
			MaxIncrementFrameSize (number): The maximum increment value of the frame size.
			MaxRandomFrameSize (number): The maximum random frame size to be sent.
			MinBinaryLoadIntegerValues (number): Min Binary Load Integer Values
			MinIncrementFrameSize (number): The minimum increment value of the frame size.
			MinRandomFrameSize (number): The minimum random frame size to be sent.
			MldVersion (number): The version of the MLD messages.
			MulticastProtocolUsed (str): The multicast protocol that is used.
			NumAddresses (number): The number address.
			Numtrials (number): Defines how many times each frame size will be tested.
			PortDelayEnabled (bool): NOT DEFINED
			PortDelayUnit (str(bytes|nanoseconds)): Sets the port delay unit in which it will be measured
			PortDelayValue (number): Sets the port delay value
			ProtocolItem (list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])): Protocol Items
			ReportTputRateUnit (str(gbps|gBps|kbps|kBps|mbps|mBps)): Report identifying the unit for measuring the throughput rate in frames per second.
			RouterAlert (bool): If enabled, it alerts the router.
			ShowDetailedBinaryResults (bool): NOT DEFINED
			StepIncrementFrameSize (number): The step increment value of the frame size.
			SupportedTrafficTypes (str): The traffic types supported.
			TestTrafficType (str): It signifies the test traffic type value.
			TxDelay (number): The delay in transmission.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyAsync(self):
		"""Executes the applyAsync operation on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsync', payload=payload, response_object=None)

	def ApplyAsyncResult(self):
		"""Executes the applyAsyncResult operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsyncResult', payload=payload, response_object=None)

	def ApplyITWizardConfiguration(self):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		Generate a PDF report for the last succesfull test run.

			Returns:
				str: This method is asynchronous and has no return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateReport', payload=payload, response_object=None)

	def Run(self, *args, **kwargs):
		"""Executes the run operation on the server.

		Starts the specified Quick Test and waits for its execution to finish.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		run()list

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		run(InputParameters:string)list
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('run', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Starts the specified Quick Test.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(InputParameters:string)
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def WaitForTest(self):
		"""Executes the waitForTest operation on the server.

		Waits for the execution of the specified Quick Test to be completed.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('waitForTest', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class DceTopologyRange(Base):
	"""The DceTopologyRange class encapsulates a user managed dceTopologyRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the DceTopologyRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'dceTopologyRange'

	def __init__(self, parent):
		super(DceTopologyRange, self).__init__(parent)

	@property
	def DceInterestedVlanRange(self):
		"""An instance of the DceInterestedVlanRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dceinterestedvlanrange.DceInterestedVlanRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.dceinterestedvlanrange import DceInterestedVlanRange
		return DceInterestedVlanRange(self)

	@property
	def EnableFtag(self):
		"""If true, the F tag is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enableFtag')
	@EnableFtag.setter
	def EnableFtag(self, value):
		self._set_attribute('enableFtag', value)

	@property
	def Enabled(self):
		"""Signifies if DCE Topology is enabled or disabled.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def NicknameList(self):
		"""The list of nicknames.

		Returns:
			list(dict(arg1:number,arg2:number,arg3:number))
		"""
		return self._get_attribute('nicknameList')
	@NicknameList.setter
	def NicknameList(self, value):
		self._set_attribute('nicknameList', value)

	@property
	def NoOfTreesToCompute(self):
		"""The number of trees to compute.

		Returns:
			number
		"""
		return self._get_attribute('noOfTreesToCompute')
	@NoOfTreesToCompute.setter
	def NoOfTreesToCompute(self, value):
		self._set_attribute('noOfTreesToCompute', value)

	@property
	def StartFtagValue(self):
		"""If true, the Ftag value is started.

		Returns:
			number
		"""
		return self._get_attribute('startFtagValue')
	@StartFtagValue.setter
	def StartFtagValue(self, value):
		self._set_attribute('startFtagValue', value)

	@property
	def TopologyCount(self):
		"""The count of the topology.

		Returns:
			number
		"""
		return self._get_attribute('topologyCount')
	@TopologyCount.setter
	def TopologyCount(self, value):
		self._set_attribute('topologyCount', value)

	@property
	def TopologyId(self):
		"""The unique identification number of the topology range.

		Returns:
			number
		"""
		return self._get_attribute('topologyId')
	@TopologyId.setter
	def TopologyId(self, value):
		self._set_attribute('topologyId', value)

	@property
	def TopologyIdStep(self):
		"""It shows the Increment Step of the ID of DCE Topology Range. Default is 1.

		Returns:
			number
		"""
		return self._get_attribute('topologyIdStep')
	@TopologyIdStep.setter
	def TopologyIdStep(self, value):
		self._set_attribute('topologyIdStep', value)

	def update(self, EnableFtag=None, Enabled=None, NicknameList=None, NoOfTreesToCompute=None, StartFtagValue=None, TopologyCount=None, TopologyId=None, TopologyIdStep=None):
		"""Updates a child instance of dceTopologyRange on the server.

		Args:
			EnableFtag (bool): If true, the F tag is enabled.
			Enabled (bool): Signifies if DCE Topology is enabled or disabled.
			NicknameList (list(dict(arg1:number,arg2:number,arg3:number))): The list of nicknames.
			NoOfTreesToCompute (number): The number of trees to compute.
			StartFtagValue (number): If true, the Ftag value is started.
			TopologyCount (number): The count of the topology.
			TopologyId (number): The unique identification number of the topology range.
			TopologyIdStep (number): It shows the Increment Step of the ID of DCE Topology Range. Default is 1.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, EnableFtag=None, Enabled=None, NicknameList=None, NoOfTreesToCompute=None, StartFtagValue=None, TopologyCount=None, TopologyId=None, TopologyIdStep=None):
		"""Adds a new dceTopologyRange node on the server and retrieves it in this instance.

		Args:
			EnableFtag (bool): If true, the F tag is enabled.
			Enabled (bool): Signifies if DCE Topology is enabled or disabled.
			NicknameList (list(dict(arg1:number,arg2:number,arg3:number))): The list of nicknames.
			NoOfTreesToCompute (number): The number of trees to compute.
			StartFtagValue (number): If true, the Ftag value is started.
			TopologyCount (number): The count of the topology.
			TopologyId (number): The unique identification number of the topology range.
			TopologyIdStep (number): It shows the Increment Step of the ID of DCE Topology Range. Default is 1.

		Returns:
			self: This instance with all currently retrieved dceTopologyRange data using find and the newly added dceTopologyRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the dceTopologyRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, EnableFtag=None, Enabled=None, NicknameList=None, NoOfTreesToCompute=None, StartFtagValue=None, TopologyCount=None, TopologyId=None, TopologyIdStep=None):
		"""Finds and retrieves dceTopologyRange data from the server.

		All named parameters support regex and can be used to selectively retrieve dceTopologyRange data from the server.
		By default the find method takes no parameters and will retrieve all dceTopologyRange data from the server.

		Args:
			EnableFtag (bool): If true, the F tag is enabled.
			Enabled (bool): Signifies if DCE Topology is enabled or disabled.
			NicknameList (list(dict(arg1:number,arg2:number,arg3:number))): The list of nicknames.
			NoOfTreesToCompute (number): The number of trees to compute.
			StartFtagValue (number): If true, the Ftag value is started.
			TopologyCount (number): The count of the topology.
			TopologyId (number): The unique identification number of the topology range.
			TopologyIdStep (number): It shows the Increment Step of the ID of DCE Topology Range. Default is 1.

		Returns:
			self: This instance with matching dceTopologyRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of dceTopologyRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the dceTopologyRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Meters(Base):
	"""The Meters class encapsulates a system managed meters node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Meters property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'meters'

	def __init__(self, parent):
		super(Meters, self).__init__(parent)

	@property
	def Bands(self):
		"""An instance of the Bands class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bands.Bands)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bands import Bands
		return Bands(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def Advertise(self):
		"""When this check box is cleared, no meter is advertised when the OpenFlow channel comes up or when the Enable check box is selected or cleared.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('advertise')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def Flags(self):
		"""Select the meter configuration flags from the list.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('flags')

	@property
	def MeterDesc(self):
		"""A description of the meter

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('meterDesc')

	@property
	def MeterId(self):
		"""The value by which a meter is uniquely identified .

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('meterId')

	@property
	def Multiplier(self):
		"""Number of instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NumberOfBands(self):
		"""Specify the number of Bands.

		Returns:
			number
		"""
		return self._get_attribute('numberOfBands')
	@NumberOfBands.setter
	def NumberOfBands(self, value):
		self._set_attribute('numberOfBands', value)

	def update(self, Multiplier=None, Name=None, NumberOfBands=None):
		"""Updates a child instance of meters on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Multiplier (number): Number of instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NumberOfBands (number): Specify the number of Bands.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, Count=None, DescriptiveName=None, Multiplier=None, Name=None, NumberOfBands=None):
		"""Finds and retrieves meters data from the server.

		All named parameters support regex and can be used to selectively retrieve meters data from the server.
		By default the find method takes no parameters and will retrieve all meters data from the server.

		Args:
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Multiplier (number): Number of instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NumberOfBands (number): Specify the number of Bands.

		Returns:
			self: This instance with matching meters data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of meters data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the meters data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, Active=None, Advertise=None, Flags=None, MeterDesc=None, MeterId=None):
		"""Base class infrastructure that gets a list of meters device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			Advertise (str): optional regex of advertise
			Flags (str): optional regex of flags
			MeterDesc (str): optional regex of meterDesc
			MeterId (str): optional regex of meterId

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def SendAllMeterAdd(self):
		"""Executes the sendAllMeterAdd operation on the server.

		Sends a Meter Add on all meters.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendAllMeterAdd', payload=payload, response_object=None)

	def SendAllMeterRemove(self):
		"""Executes the sendAllMeterRemove operation on the server.

		Sends a Meter Remove on all meters.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendAllMeterRemove', payload=payload, response_object=None)

	def SendMeterAdd(self, *args, **kwargs):
		"""Executes the sendMeterAdd operation on the server.

		Sends a Meter Add on selected Meter.

		sendMeterAdd(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the meter range grid

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendMeterAdd', payload=payload, response_object=None)

	def SendMeterRemove(self, *args, **kwargs):
		"""Executes the sendMeterRemove operation on the server.

		Sends a Meter Remove on selected Meter.

		sendMeterRemove(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the meter range grid

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendMeterRemove', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Lacp(Base):
	"""The Lacp class encapsulates a required lacp node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Lacp property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'lacp'

	def __init__(self, parent):
		super(Lacp, self).__init__(parent)

	@property
	def LearnedInfo(self):
		"""An instance of the LearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.lacp.learnedinfo.learnedinfo.LearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.lacp.learnedinfo.learnedinfo import LearnedInfo
		return LearnedInfo(self)

	@property
	def Link(self):
		"""An instance of the Link class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.lacp.link.link.Link)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.lacp.link.link import Link
		return Link(self)

	@property
	def EnablePreservePartnerInfo(self):
		"""If true, the fields of previous link are updatedw

		Returns:
			bool
		"""
		return self._get_attribute('enablePreservePartnerInfo')
	@EnablePreservePartnerInfo.setter
	def EnablePreservePartnerInfo(self, value):
		self._set_attribute('enablePreservePartnerInfo', value)

	@property
	def Enabled(self):
		"""If true, the Link Aggregation Control Protocol (LACP) is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def IsLacpPortLearnedInfoRefreshed(self):
		"""(read only) If true, the learned port information is up to date.

		Returns:
			bool
		"""
		return self._get_attribute('isLacpPortLearnedInfoRefreshed')

	@property
	def RunningState(self):
		"""The current running state of LACP.

		Returns:
			str(unknown|stopped|stopping|starting|started)
		"""
		return self._get_attribute('runningState')

	def update(self, EnablePreservePartnerInfo=None, Enabled=None):
		"""Updates a child instance of lacp on the server.

		Args:
			EnablePreservePartnerInfo (bool): If true, the fields of previous link are updatedw
			Enabled (bool): If true, the Link Aggregation Control Protocol (LACP) is enabled.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def RefreshLacpPortLearnedInfo(self):
		"""Executes the refreshLacpPortLearnedInfo operation on the server.

		This exec refreshes the LACP port learned information.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshLacpPortLearnedInfo', payload=payload, response_object=None)

	def SendMarkerRequest(self):
		"""Executes the sendMarkerRequest operation on the server.

		This sends a marker request. The contents of the marker PDU contain the current view of partner (which can be defaulted if no partner is present). The marker will be sent regardless of which state the link is in.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendMarkerRequest', payload=payload, response_object=None)

	def SendUpdate(self):
		"""Executes the sendUpdate operation on the server.

		This exec sends an update to the actor's partners after a change has been made to the link's parameters.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendUpdate', payload=payload, response_object=None)

	def Start(self):
		"""Executes the start operation on the server.

		This exec starts the LACP protocol.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('start', payload=payload, response_object=None)

	def StartPdu(self):
		"""Executes the startPdu operation on the server.

		This exec starts PDUs related to LACP (for example, LACPDU, Marker Request PDU, Marker Response PDU) while the protocol is running on the port.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('startPdu', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		This exec stops the LACP protocol.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def StopPdu(self):
		"""Executes the stopPdu operation on the server.

		This exec stops PDUs related to LACP (for example, LACPDU, Marker Request PDU, Marker Response PDU) while the protocol is running on the port.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stopPdu', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class BroadcastDomainV6VxlanVpws(Base):
	"""The BroadcastDomainV6VxlanVpws class encapsulates a required broadcastDomainV6VxlanVpws node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the BroadcastDomainV6VxlanVpws property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'broadcastDomainV6VxlanVpws'

	def __init__(self, parent):
		super(BroadcastDomainV6VxlanVpws, self).__init__(parent)

	@property
	def PnTLVList(self):
		"""An instance of the PnTLVList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pntlvlist.PnTLVList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pntlvlist import PnTLVList
		return PnTLVList(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def AdRouteLabel(self):
		"""AD Route Label

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('adRouteLabel')

	@property
	def BVlanId(self):
		"""B VLAN ID

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bVlanId')

	@property
	def BVlanPriority(self):
		"""B VLAN Priority

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bVlanPriority')

	@property
	def BVlanTpid(self):
		"""B VLAN TPID

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bVlanTpid')

	@property
	def BackupFlag(self):
		"""Backup Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('backupFlag')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def EnableVlanAwareService(self):
		"""Enable VLAN Aware Service

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableVlanAwareService')

	@property
	def EthernetTagId(self):
		"""Ethernet Tag ID. For VPWS, this acts as VPWS Service ID

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ethernetTagId')

	@property
	def FxcType(self):
		"""FXC Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('fxcType')

	@property
	def GroupAddress(self):
		"""Group Address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('groupAddress')

	@property
	def IncludeVpwsL2AttrExtComm(self):
		"""Include VPWS Layer 2 Attributes Extended Community

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeVpwsL2AttrExtComm')

	@property
	def L2Mtu(self):
		"""L2 MTU

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('l2Mtu')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NoOfMacPools(self):
		"""Number of Mac Pools

		Returns:
			number
		"""
		return self._get_attribute('noOfMacPools')
	@NoOfMacPools.setter
	def NoOfMacPools(self, value):
		self._set_attribute('noOfMacPools', value)

	@property
	def PrimaryPE(self):
		"""Primary PE

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('primaryPE')

	@property
	def RemoteServiceId(self):
		"""Remote Service ID

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('remoteServiceId')

	@property
	def RequireCW(self):
		"""Require CW

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('requireCW')

	@property
	def RootAddress(self):
		"""Root Address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rootAddress')

	@property
	def RsvpP2mpId(self):
		"""RSVP P2MP ID

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rsvpP2mpId')

	@property
	def RsvpP2mpIdAsNumber(self):
		"""RSVP P2MP ID as Number

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rsvpP2mpIdAsNumber')

	@property
	def RsvpTunnelId(self):
		"""RSVP Tunnel ID

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rsvpTunnelId')

	@property
	def SenderAddressPRootNodeAddress(self):
		"""Sender Address/P-Root Node Address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('senderAddressPRootNodeAddress')

	@property
	def UsebVlan(self):
		"""Use B-VLAN

		Returns:
			bool
		"""
		return self._get_attribute('usebVlan')
	@UsebVlan.setter
	def UsebVlan(self, value):
		self._set_attribute('usebVlan', value)

	@property
	def VidNormalization(self):
		"""VID Normalization

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('vidNormalization')

	def update(self, Name=None, NoOfMacPools=None, UsebVlan=None):
		"""Updates a child instance of broadcastDomainV6VxlanVpws on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NoOfMacPools (number): Number of Mac Pools
			UsebVlan (bool): Use B-VLAN

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def get_device_ids(self, PortNames=None, Active=None, AdRouteLabel=None, BVlanId=None, BVlanPriority=None, BVlanTpid=None, BackupFlag=None, EnableVlanAwareService=None, EthernetTagId=None, FxcType=None, GroupAddress=None, IncludeVpwsL2AttrExtComm=None, L2Mtu=None, PrimaryPE=None, RemoteServiceId=None, RequireCW=None, RootAddress=None, RsvpP2mpId=None, RsvpP2mpIdAsNumber=None, RsvpTunnelId=None, SenderAddressPRootNodeAddress=None, VidNormalization=None):
		"""Base class infrastructure that gets a list of broadcastDomainV6VxlanVpws device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			AdRouteLabel (str): optional regex of adRouteLabel
			BVlanId (str): optional regex of bVlanId
			BVlanPriority (str): optional regex of bVlanPriority
			BVlanTpid (str): optional regex of bVlanTpid
			BackupFlag (str): optional regex of backupFlag
			EnableVlanAwareService (str): optional regex of enableVlanAwareService
			EthernetTagId (str): optional regex of ethernetTagId
			FxcType (str): optional regex of fxcType
			GroupAddress (str): optional regex of groupAddress
			IncludeVpwsL2AttrExtComm (str): optional regex of includeVpwsL2AttrExtComm
			L2Mtu (str): optional regex of l2Mtu
			PrimaryPE (str): optional regex of primaryPE
			RemoteServiceId (str): optional regex of remoteServiceId
			RequireCW (str): optional regex of requireCW
			RootAddress (str): optional regex of rootAddress
			RsvpP2mpId (str): optional regex of rsvpP2mpId
			RsvpP2mpIdAsNumber (str): optional regex of rsvpP2mpIdAsNumber
			RsvpTunnelId (str): optional regex of rsvpTunnelId
			SenderAddressPRootNodeAddress (str): optional regex of senderAddressPRootNodeAddress
			VidNormalization (str): optional regex of vidNormalization

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class LmiStatusLearnedInfo(Base):
	"""The LmiStatusLearnedInfo class encapsulates a system managed lmiStatusLearnedInfo node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the LmiStatusLearnedInfo property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'lmiStatusLearnedInfo'

	def __init__(self, parent):
		super(LmiStatusLearnedInfo, self).__init__(parent)

	@property
	def DataInstance(self):
		"""This four-octet field indicates the Data Instance value to be sent in transmitted packet. It will be configurable only if Override Data Instance is enabled. By default it is grayed out with default value 0x0 for UNI-C and 0x1 for UNI-N. Max 4 octet max value, Min 0/1. Change of value in this field takes effect when protocol is running.

		Returns:
			number
		"""
		return self._get_attribute('dataInstance')

	@property
	def DuplicatedIe(self):
		"""Type of out of sequence IE received : count of out of sequence IE received.

		Returns:
			str
		"""
		return self._get_attribute('duplicatedIe')

	@property
	def InvalidEvcReferenceId(self):
		"""Invalid EVC reference Id.

		Returns:
			str
		"""
		return self._get_attribute('invalidEvcReferenceId')

	@property
	def InvalidMandatoryIe(self):
		"""Type of invalid mandatory IE : count of invalid mandatory IE.

		Returns:
			str
		"""
		return self._get_attribute('invalidMandatoryIe')

	@property
	def InvalidMsgType(self):
		"""It signfies the invalid message type.

		Returns:
			str
		"""
		return self._get_attribute('invalidMsgType')

	@property
	def InvalidNonMandatoryIe(self):
		"""Type of invalid non mandatory IE : count of invalid non mandatory IE

		Returns:
			str
		"""
		return self._get_attribute('invalidNonMandatoryIe')

	@property
	def InvalidProtocolVersion(self):
		"""Invalid protocol version in received ELMI message.

		Returns:
			str
		"""
		return self._get_attribute('invalidProtocolVersion')

	@property
	def LmiStatus(self):
		"""It signifies the LMI status value.

		Returns:
			str
		"""
		return self._get_attribute('lmiStatus')

	@property
	def MandatoryIeMissing(self):
		"""Type of mandatory IE missing : count of mandatory IE missing.

		Returns:
			str
		"""
		return self._get_attribute('mandatoryIeMissing')

	@property
	def OutOfSequenceIe(self):
		"""Type of out of sequence IE received : count of out of sequence IE recieved

		Returns:
			str
		"""
		return self._get_attribute('outOfSequenceIe')

	@property
	def ProtocolVersion(self):
		"""This one-octet field indicates the version supported by the sending

		Returns:
			number
		"""
		return self._get_attribute('protocolVersion')

	@property
	def ReceiveSequenceNumber(self):
		"""The value of Receive Sequence Number in received ELMI message.

		Returns:
			number
		"""
		return self._get_attribute('receiveSequenceNumber')

	@property
	def SendSequenceNumber(self):
		"""The value of Send Sequence Number in received ELMI message.

		Returns:
			number
		"""
		return self._get_attribute('sendSequenceNumber')

	@property
	def ShortMsgCounter(self):
		"""It signifies the short message counter value.

		Returns:
			number
		"""
		return self._get_attribute('shortMsgCounter')

	@property
	def UnexpectedIe(self):
		"""Type of unexpected IE : count of unexpected IE.

		Returns:
			str
		"""
		return self._get_attribute('unexpectedIe')

	@property
	def UnrecognizedIe(self):
		"""Type of unrecognized IE : count of unrecognized IE.

		Returns:
			str
		"""
		return self._get_attribute('unrecognizedIe')

	def find(self, DataInstance=None, DuplicatedIe=None, InvalidEvcReferenceId=None, InvalidMandatoryIe=None, InvalidMsgType=None, InvalidNonMandatoryIe=None, InvalidProtocolVersion=None, LmiStatus=None, MandatoryIeMissing=None, OutOfSequenceIe=None, ProtocolVersion=None, ReceiveSequenceNumber=None, SendSequenceNumber=None, ShortMsgCounter=None, UnexpectedIe=None, UnrecognizedIe=None):
		"""Finds and retrieves lmiStatusLearnedInfo data from the server.

		All named parameters support regex and can be used to selectively retrieve lmiStatusLearnedInfo data from the server.
		By default the find method takes no parameters and will retrieve all lmiStatusLearnedInfo data from the server.

		Args:
			DataInstance (number): This four-octet field indicates the Data Instance value to be sent in transmitted packet. It will be configurable only if Override Data Instance is enabled. By default it is grayed out with default value 0x0 for UNI-C and 0x1 for UNI-N. Max 4 octet max value, Min 0/1. Change of value in this field takes effect when protocol is running.
			DuplicatedIe (str): Type of out of sequence IE received : count of out of sequence IE received.
			InvalidEvcReferenceId (str): Invalid EVC reference Id.
			InvalidMandatoryIe (str): Type of invalid mandatory IE : count of invalid mandatory IE.
			InvalidMsgType (str): It signfies the invalid message type.
			InvalidNonMandatoryIe (str): Type of invalid non mandatory IE : count of invalid non mandatory IE
			InvalidProtocolVersion (str): Invalid protocol version in received ELMI message.
			LmiStatus (str): It signifies the LMI status value.
			MandatoryIeMissing (str): Type of mandatory IE missing : count of mandatory IE missing.
			OutOfSequenceIe (str): Type of out of sequence IE received : count of out of sequence IE recieved
			ProtocolVersion (number): This one-octet field indicates the version supported by the sending
			ReceiveSequenceNumber (number): The value of Receive Sequence Number in received ELMI message.
			SendSequenceNumber (number): The value of Send Sequence Number in received ELMI message.
			ShortMsgCounter (number): It signifies the short message counter value.
			UnexpectedIe (str): Type of unexpected IE : count of unexpected IE.
			UnrecognizedIe (str): Type of unrecognized IE : count of unrecognized IE.

		Returns:
			self: This instance with matching lmiStatusLearnedInfo data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of lmiStatusLearnedInfo data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the lmiStatusLearnedInfo data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)
